==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredActionProviderEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapRequiredActionProviderEntityDelegate implements org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> delegateProvider;
    public MapRequiredActionProviderEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME, name).setName(name);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public Integer getPriority() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY).getPriority();
    }
    @Override public void setPriority(Integer priority) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY, priority).setPriority(priority);
    }
    @Override public Boolean isEnabled() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED).isEnabled();
    }
    @Override public void setEnabled(Boolean enabled) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED, enabled).setEnabled(enabled);
    }
    @Override public Boolean isDefaultAction() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION).isDefaultAction();
    }
    @Override public void setDefaultAction(Boolean defaultAction) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION, defaultAction).setDefaultAction(defaultAction);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG, config).setConfig(config);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredActionProviderEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapRequiredActionProviderEntityDelegate implements org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> delegateProvider;
    public MapRequiredActionProviderEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME, name).setName(name);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public Integer getPriority() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY).getPriority();
    }
    @Override public void setPriority(Integer priority) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY, priority).setPriority(priority);
    }
    @Override public Boolean isEnabled() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED).isEnabled();
    }
    @Override public void setEnabled(Boolean enabled) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED, enabled).setEnabled(enabled);
    }
    @Override public Boolean isDefaultAction() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION).isDefaultAction();
    }
    @Override public void setDefaultAction(Boolean defaultAction) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION, defaultAction).setDefaultAction(defaultAction);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG, config).setConfig(config);
    }
}
